@@ -4,10 +4,11 @@ Note
 ----
 This is an internal API not covered by versioning policy.
 """
+
 import re
 import traceback
 import typing as t
-from collections.abc import Mapping, Sequence
+from collections.abc import Iterable, Mapping, Sequence
 
 if t.TYPE_CHECKING:
 
@@ -19,17 +20,17 @@ if t.TYPE_CHECKING:
             data: t.Union[str, t.List[str], "Mapping[str, str]"],
             rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
         ) -> bool:
-            """Callback for :class:`QueryList` filtering operators."""
+            """Return callback for :class:`QueryList` filtering operators."""
             ...
 
 
-T = t.TypeVar("T", t.Any, t.Any)
+T = t.TypeVar("T")
 
 no_arg = object()
 
 
 class MultipleObjectsReturned(Exception):
-    """The requested object does not exist"""
+    """The requested object does not exist."""
 
 
 class ObjectDoesNotExist(Exception):
@@ -40,13 +41,55 @@ def keygetter(
     obj: "Mapping[str, t.Any]",
     path: str,
 ) -> t.Union[None, t.Any, str, t.List[str], "Mapping[str, str]"]:
-    """obj, "foods__breakfast", obj['foods']['breakfast']
+    """Fetch values in objects and keys, supported nested data.
 
-    >>> keygetter({ "foods": { "breakfast": "cereal" } }, "foods__breakfast")
-    'cereal'
-    >>> keygetter({ "foods": { "breakfast": "cereal" } }, "foods")
+    **With dictionaries**:
+
+    >>> keygetter({ "food": { "breakfast": "cereal" } }, "food")
     {'breakfast': 'cereal'}
 
+    >>> keygetter({ "food": { "breakfast": "cereal" } }, "food__breakfast")
+    'cereal'
+
+    **With objects**:
+
+    >>> from typing import List, Optional
+    >>> from dataclasses import dataclass, field
+
+    >>> @dataclass()
+    ... class Food:
+    ...     fruit: List[str] = field(default_factory=list)
+    ...     breakfast: Optional[str] = None
+
+
+    >>> @dataclass()
+    ... class Restaurant:
+    ...     place: str
+    ...     city: str
+    ...     state: str
+    ...     food: Food = field(default_factory=Food)
+
+
+    >>> restaurant = Restaurant(
+    ...     place="Largo",
+    ...     city="Tampa",
+    ...     state="Florida",
+    ...     food=Food(
+    ...         fruit=["banana", "orange"], breakfast="cereal"
+    ...     )
+    ... )
+
+    >>> restaurant
+    Restaurant(place='Largo',
+        city='Tampa',
+        state='Florida',
+        food=Food(fruit=['banana', 'orange'], breakfast='cereal'))
+
+    >>> keygetter(restaurant, "food")
+    Food(fruit=['banana', 'orange'], breakfast='cereal')
+
+    >>> keygetter(restaurant, "food__breakfast")
+    'cereal'
     """
     try:
         sub_fields = path.split("__")
@@ -66,16 +109,32 @@ def keygetter(
 
 
 def parse_lookup(
-    obj: "Mapping[str, t.Any]", path: str, lookup: str
+    obj: "Mapping[str, t.Any]",
+    path: str,
+    lookup: str,
 ) -> t.Optional[t.Any]:
     """Check if field lookup key, e.g. "my__path__contains" has comparator, return val.
 
     If comparator not used or value not found, return None.
 
-    mykey__endswith("mykey") -> "mykey" else None
-
     >>> parse_lookup({ "food": "red apple" }, "food__istartswith", "__istartswith")
     'red apple'
+
+    It can also look up objects:
+
+    >>> from dataclasses import dataclass
+
+    >>> @dataclass()
+    ... class Inventory:
+    ...     food: str
+
+    >>> item = Inventory(food="red apple")
+
+    >>> item
+    Inventory(food='red apple')
+
+    >>> parse_lookup(item, "food__istartswith", "__istartswith")
+    'red apple'
     """
     try:
         if isinstance(path, str) and isinstance(lookup, str) and path.endswith(lookup):
@@ -257,11 +316,13 @@ class OpNotFound(ValueError):
         return super().__init__(f"{op} not in LOOKUP_NAME_MAP")
 
 
-class QueryList(t.List[T]):
+class QueryList(t.Generic[T], t.List[T]):
     """Filter list of object/dictionaries. For small, local datasets.
 
     *Experimental, unstable*.
 
+    **With dictionaries**:
+
     >>> query = QueryList(
     ...     [
     ...         {
@@ -278,6 +339,7 @@ class QueryList(t.List[T]):
     ...         },
     ...     ]
     ... )
+
     >>> query.filter(place="Chicago suburbs")[0]['city']
     'Elmhurst'
     >>> query.filter(place__icontains="chicago")[0]['city']
@@ -288,14 +350,128 @@ class QueryList(t.List[T]):
     'Elmhurst'
     >>> query.filter(foods__fruit__in="orange")[0]['city']
     'Tampa'
-    >>> query.get(foods__fruit__in="orange")['city']
+
+    >>> query.filter(foods__fruit__in="apple")
+    [{'place': 'Chicago suburbs',
+        'city': 'Elmhurst',
+        'state': 'Illinois',
+        'foods':
+            {'fruit': ['apple', 'cantelope'], 'breakfast': 'waffles'}}]
+
+    >>> query.filter(foods__fruit__in="non_existent")
+    []
+
+    **With objects**:
+
+    >>> from typing import Any, Dict
+    >>> from dataclasses import dataclass, field
+
+    >>> @dataclass()
+    ... class Restaurant:
+    ...     place: str
+    ...     city: str
+    ...     state: str
+    ...     foods: Dict[str, Any]
+
+    >>> restaurant = Restaurant(
+    ...     place="Largo",
+    ...     city="Tampa",
+    ...     state="Florida",
+    ...     foods={
+    ...         "fruit": ["banana", "orange"], "breakfast": "cereal"
+    ...     }
+    ... )
+
+    >>> restaurant
+    Restaurant(place='Largo',
+        city='Tampa',
+        state='Florida',
+        foods={'fruit': ['banana', 'orange'], 'breakfast': 'cereal'})
+
+    >>> query = QueryList([restaurant])
+
+    >>> query.filter(foods__fruit__in="banana")
+    [Restaurant(place='Largo',
+        city='Tampa',
+        state='Florida',
+        foods={'fruit': ['banana', 'orange'], 'breakfast': 'cereal'})]
+
+    >>> query.filter(foods__fruit__in="banana")[0].city
     'Tampa'
+
+    >>> query.get(foods__fruit__in="banana").city
+    'Tampa'
+
+    **With objects (nested)**:
+
+    >>> from typing import List, Optional
+    >>> from dataclasses import dataclass, field
+
+    >>> @dataclass()
+    ... class Food:
+    ...     fruit: List[str] = field(default_factory=list)
+    ...     breakfast: Optional[str] = None
+
+
+    >>> @dataclass()
+    ... class Restaurant:
+    ...     place: str
+    ...     city: str
+    ...     state: str
+    ...     food: Food = field(default_factory=Food)
+
+
+    >>> query = QueryList([
+    ...     Restaurant(
+    ...         place="Largo",
+    ...         city="Tampa",
+    ...         state="Florida",
+    ...         food=Food(
+    ...             fruit=["banana", "orange"], breakfast="cereal"
+    ...         )
+    ...     ),
+    ...     Restaurant(
+    ...         place="Chicago suburbs",
+    ...         city="Elmhurst",
+    ...         state="Illinois",
+    ...         food=Food(
+    ...             fruit=["apple", "cantelope"], breakfast="waffles"
+    ...         )
+    ...     )
+    ... ])
+
+    >>> query.filter(food__fruit__in="banana")
+    [Restaurant(place='Largo',
+        city='Tampa',
+        state='Florida',
+        food=Food(fruit=['banana', 'orange'], breakfast='cereal'))]
+
+    >>> query.filter(food__fruit__in="banana")[0].city
+    'Tampa'
+
+    >>> query.get(food__fruit__in="banana").city
+    'Tampa'
+
+    >>> query.filter(food__breakfast="waffles")
+    [Restaurant(place='Chicago suburbs',
+        city='Elmhurst',
+        state='Illinois',
+        food=Food(fruit=['apple', 'cantelope'], breakfast='waffles'))]
+
+    >>> query.filter(food__breakfast="waffles")[0].city
+    'Elmhurst'
+
+    >>> query.filter(food__breakfast="non_existent")
+    []
     """
 
     data: "Sequence[T]"
     pk_key: t.Optional[str]
 
-    def items(self) -> t.List[T]:
+    def __init__(self, items: t.Optional["Iterable[T]"] = None) -> None:
+        super().__init__(items if items is not None else [])
+
+    def items(self) -> t.List[t.Tuple[str, T]]:
         if self.pk_key is None:
             raise PKRequiredException()
         return [(getattr(item, self.pk_key), item) for item in self]
@@ -303,12 +479,6 @@ class QueryList(t.List[T]):
     def __eq__(
         self,
         other: object,
-        # other: t.Union[
-        #     "QueryList[T]",
-        #     t.List[Mapping[str, str]],
-        #     t.List[Mapping[str, int]],
-        #     t.List[Mapping[str, t.Union[str, Mapping[str, t.Union[List[str], str]]]]],
-        # ],
     ) -> bool:
         data = other
 
@@ -361,7 +531,7 @@ class QueryList(t.List[T]):
             _filter = matcher
         elif matcher is not None:
 
-            def val_match(obj: t.Union[str, t.List[t.Any]]) -> bool:
+            def val_match(obj: t.Union[str, t.List[t.Any], T]) -> bool:
                 if isinstance(matcher, list):
                     return obj in matcher
                 else:
