@@ -7,15 +7,19 @@ libtmux.pane
 
 import dataclasses
 import logging
+import pathlib
 import typing as t
 import warnings
 from typing import overload
 
-from libtmux.common import has_gte_version, tmux_cmd
+from libtmux.common import has_gte_version, has_lt_version, tmux_cmd
 from libtmux.constants import (
+    PANE_DIRECTION_FLAG_MAP,
     RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    PaneDirection,
     ResizeAdjustmentDirection,
 )
+from libtmux.formats import FORMAT_SEPARATOR
 from libtmux.neo import Obj, fetch_obj
 
 from . import exc
@@ -113,11 +117,16 @@ class Pane(Obj):
     Commands (pane-scoped)
     """
 
-    def cmd(self, cmd: str, *args: t.Any) -> tmux_cmd:
+    def cmd(
+        self,
+        cmd: str,
+        *args: t.Any,
+        target: t.Optional[t.Union[str, int]] = None,
+    ) -> tmux_cmd:
         """Execute tmux subcommand within pane context.
 
-        Automatically adds ``-t`` for object's pane ID to the command. Pass ``-t``
-        in args to override.
+        Automatically binds target by adding  ``-t`` for object's pane ID to the
+        command. Pass ``target`` to keyword arguments to override.
 
         Examples
         --------
@@ -130,14 +139,19 @@ class Pane(Obj):
         ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=pane.server)
         Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
 
+        Parameters
+        ----------
+        target : str, optional
+            Optional custom target override. By default, the target is the pane ID.
+
         Returns
         -------
         :meth:`server.cmd`
         """
-        if not any("-t" in str(x) for x in args):
-            args = ("-t", self.pane_id, *args)
+        if target is None:
+            target = self.pane_id
 
-        return self.server.cmd(cmd, *args)
+        return self.server.cmd(cmd, *args, target=target)
 
     """
     Commands (tmux-like)
@@ -145,6 +159,7 @@ class Pane(Obj):
 
     def resize(
         self,
+        /,
         # Adjustments
         adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
         adjustment: t.Optional[int] = None,
@@ -308,7 +323,7 @@ class Pane(Obj):
 
         Examples
         --------
-        >>> pane = window.split_window(shell='sh')
+        >>> pane = window.split(shell='sh')
         >>> pane.capture_pane()
         ['$']
 
@@ -377,7 +392,7 @@ class Pane(Obj):
         --------
         Kill a pane:
 
-        >>> pane_1 = pane.split_window()
+        >>> pane_1 = pane.split()
 
         >>> pane_1 in window.panes
         True
@@ -392,10 +407,10 @@ class Pane(Obj):
         >>> pane.window.resize(height=100, width=100)
         Window(@1 1...)
 
-        >>> one_pane_to_rule_them_all = pane.split_window()
+        >>> one_pane_to_rule_them_all = pane.split()
 
-        >>> other_panes = pane.split_window(
-        ...     ), pane.split_window()
+        >>> other_panes = pane.split(
+        ...     ), pane.split()
 
         >>> all([p in window.panes for p in other_panes])
         True
@@ -436,7 +451,7 @@ class Pane(Obj):
         Examples
         --------
         >>> pane = window.active_pane
-        >>> new_pane = window.split_window()
+        >>> new_pane = window.split()
         >>> pane.refresh()
         >>> active_panes = [p for p in window.panes if p.pane_active == '1']
 
@@ -483,47 +498,166 @@ class Pane(Obj):
             raise exc.PaneNotFound(pane_id=self.pane_id)
         return pane
 
-    def split_window(
+    def split(
         self,
-        attach: bool = False,
+        /,
+        target: t.Optional[t.Union[int, str]] = None,
         start_directory: t.Optional[str] = None,
-        vertical: bool = True,
+        attach: bool = False,
+        direction: t.Optional[PaneDirection] = None,
+        full_window_split: t.Optional[bool] = None,
+        zoom: t.Optional[bool] = None,
         shell: t.Optional[str] = None,
         size: t.Optional[t.Union[str, int]] = None,
-        percent: t.Optional[int] = None,  # deprecated
         environment: t.Optional[t.Dict[str, str]] = None,
-    ) -> "Pane":  # New Pane, not self
-        """Split window at pane and return newly created :class:`Pane`.
+    ) -> "Pane":
+        """Split window and return :class:`Pane`, by default beneath current pane.
 
         Parameters
         ----------
+        target : optional
+            Optional, custom *target-pane*, used by :meth:`Window.split`.
         attach : bool, optional
-            Attach / select pane after creation.
+            make new window the current window after creating it, default
+            True.
         start_directory : str, optional
-            specifies the working directory in which the new pane is created.
-        vertical : bool, optional
-            split vertically
-        percent: int, optional
-            percentage to occupy with respect to current pane
+            specifies the working directory in which the new window is created.
+        direction : PaneDirection, optional
+            split in direction. If none is specified, assume down.
+        full_window_split: bool, optional
+            split across full window width or height, rather than active pane.
+        zoom: bool, optional
+            expand pane
+        shell : str, optional
+            execute a command on splitting the window.  The pane will close
+            when the command exits.
+
+            NOTE: When this command exits the pane will close.  This feature
+            is useful for long-running processes where the closing of the
+            window upon completion is desired.
+        size: int, optional
+            Cell/row or percentage to occupy with respect to current window.
         environment: dict, optional
             Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
 
-        Notes
-        -----
-        .. deprecated:: 0.28.0
+        Examples
+        --------
+        >>> (pane.at_left, pane.at_right,
+        ...  pane.at_top, pane.at_bottom)
+        (True, True,
+        True, True)
 
-           ``percent=25`` deprecated in favor of ``size="25%"``.
+        >>> new_pane = pane.split()
+
+        >>> (new_pane.at_left, new_pane.at_right,
+        ...  new_pane.at_top, new_pane.at_bottom)
+        (True, True,
+        False, True)
+
+        >>> right_pane = pane.split(direction=PaneDirection.Right)
+
+        >>> (right_pane.at_left, right_pane.at_right,
+        ...  right_pane.at_top, right_pane.at_bottom)
+        (False, True,
+        True, False)
+
+        >>> left_pane = pane.split(direction=PaneDirection.Left)
+
+        >>> (left_pane.at_left, left_pane.at_right,
+        ...  left_pane.at_top, left_pane.at_bottom)
+        (True, False,
+        True, False)
+
+        >>> top_pane = pane.split(direction=PaneDirection.Above)
+
+        >>> (top_pane.at_left, top_pane.at_right,
+        ...  top_pane.at_top, top_pane.at_bottom)
+        (False, False,
+        True, False)
+
+        >>> pane = session.new_window().active_pane
+
+        >>> top_pane = pane.split(direction=PaneDirection.Above, full_window_split=True)
+
+        >>> (top_pane.at_left, top_pane.at_right,
+        ...  top_pane.at_top, top_pane.at_bottom)
+        (True, True,
+        True, False)
+
+        >>> bottom_pane = pane.split(
+        ... direction=PaneDirection.Below,
+        ... full_window_split=True)
+
+        >>> (bottom_pane.at_left, bottom_pane.at_right,
+        ...  bottom_pane.at_top, bottom_pane.at_bottom)
+        (True, True,
+        False, True)
         """
-        return self.window.split_window(
-            target=self.pane_id,
-            attach=attach,
-            start_directory=start_directory,
-            vertical=vertical,
-            shell=shell,
-            size=size,
-            percent=percent,
-            environment=environment,
-        )
+        tmux_formats = ["#{pane_id}" + FORMAT_SEPARATOR]
+
+        tmux_args: t.Tuple[str, ...] = ()
+
+        if direction:
+            tmux_args += tuple(PANE_DIRECTION_FLAG_MAP[direction])
+        else:
+            tmux_args += tuple(PANE_DIRECTION_FLAG_MAP[PaneDirection.Below])
+
+        if size is not None:
+            if has_lt_version("3.1"):
+                if isinstance(size, str) and size.endswith("%"):
+                    tmux_args += (f'-p{str(size).rstrip("%")}',)
+                else:
+                    warnings.warn(
+                        'Ignored size. Use percent in tmux < 3.1, e.g. "size=50%"',
+                        stacklevel=2,
+                    )
+            else:
+                tmux_args += (f"-l{size}",)
+
+        if full_window_split:
+            tmux_args += ("-f",)
+
+        if zoom:
+            tmux_args += ("-Z",)
+
+        tmux_args += ("-P", "-F%s" % "".join(tmux_formats))  # output
+
+        if start_directory is not None:
+            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
+            start_path = pathlib.Path(start_directory).expanduser()
+            tmux_args += (f"-c{start_path}",)
+
+        if not attach:
+            tmux_args += ("-d",)
+
+        if environment:
+            if has_gte_version("3.0"):
+                for k, v in environment.items():
+                    tmux_args += (f"-e{k}={v}",)
+            else:
+                logger.warning(
+                    "Environment flag ignored, tmux 3.0 or newer required.",
+                )
+
+        if shell:
+            tmux_args += (shell,)
+
+        pane_cmd = self.cmd("split-window", *tmux_args, target=target)
+
+        # tmux < 1.7. This is added in 1.7.
+        if pane_cmd.stderr:
+            if "pane too small" in pane_cmd.stderr:
+                raise exc.LibTmuxException(pane_cmd.stderr)
+
+            raise exc.LibTmuxException(
+                pane_cmd.stderr, self.__dict__, self.window.panes
+            )
+
+        pane_output = pane_cmd.stdout[0]
+
+        pane_formatters = dict(zip(["pane_id"], pane_output.split(FORMAT_SEPARATOR)))
+
+        return self.from_pane_id(server=self.server, pane_id=pane_formatters["pane_id"])
 
     """
     Commands (helpers)
@@ -633,9 +767,106 @@ class Pane(Obj):
         """
         return self.pane_width
 
+    @property
+    def at_top(self) -> bool:
+        """Typed, converted wrapper around :attr:`Pane.pane_at_top`.
+
+        >>> pane.pane_at_top
+        '1'
+
+        >>> pane.at_top
+        True
+        """
+        return self.pane_at_top == "1"
+
+    @property
+    def at_bottom(self) -> bool:
+        """Typed, converted wrapper around :attr:`Pane.pane_at_bottom`.
+
+        >>> pane.pane_at_bottom
+        '1'
+
+        >>> pane.at_bottom
+        True
+        """
+        return self.pane_at_bottom == "1"
+
+    @property
+    def at_left(self) -> bool:
+        """Typed, converted wrapper around :attr:`Pane.pane_at_left`.
+
+        >>> pane.pane_at_left
+        '1'
+
+        >>> pane.at_left
+        True
+        """
+        return self.pane_at_left == "1"
+
+    @property
+    def at_right(self) -> bool:
+        """Typed, converted wrapper around :attr:`Pane.pane_at_right`.
+
+        >>> pane.pane_at_right
+        '1'
+
+        >>> pane.at_right
+        True
+        """
+        return self.pane_at_right == "1"
+
     #
     # Legacy: Redundant stuff we want to remove
     #
+    def split_window(
+        self,
+        target: t.Optional[t.Union[int, str]] = None,
+        attach: bool = False,
+        start_directory: t.Optional[str] = None,
+        vertical: bool = True,
+        shell: t.Optional[str] = None,
+        size: t.Optional[t.Union[str, int]] = None,
+        percent: t.Optional[int] = None,  # deprecated
+        environment: t.Optional[t.Dict[str, str]] = None,
+    ) -> "Pane":  # New Pane, not self
+        """Split window at pane and return newly created :class:`Pane`.
+
+        Parameters
+        ----------
+        attach : bool, optional
+            Attach / select pane after creation.
+        start_directory : str, optional
+            specifies the working directory in which the new pane is created.
+        vertical : bool, optional
+            split vertically
+        percent: int, optional
+            percentage to occupy with respect to current pane
+        environment: dict, optional
+            Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
+
+        Notes
+        -----
+        .. deprecated:: 0.33
+
+           Deprecated in favor of :meth:`.split`.
+        """
+        warnings.warn(
+            "Pane.split_window() is deprecated in favor of Pane.split()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        if size is None and percent is not None:
+            size = f'{str(percent).rstrip("%")}%'
+        return self.split(
+            target=target,
+            attach=attach,
+            start_directory=start_directory,
+            direction=PaneDirection.Below if vertical else PaneDirection.Right,
+            shell=shell,
+            size=size,
+            environment=environment,
+        )
+
     def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
         """Return key-based lookup. Deprecated by attributes.
 
