@@ -13,6 +13,7 @@ import warnings
 
 from libtmux._internal.query_list import QueryList
 from libtmux.common import tmux_cmd
+from libtmux.constants import WINDOW_DIRECTION_FLAG_MAP, WindowDirection
 from libtmux.formats import FORMAT_SEPARATOR
 from libtmux.neo import Obj, fetch_obj, fetch_objs
 from libtmux.pane import Pane
@@ -140,11 +141,13 @@ class Session(Obj, EnvironmentMixin):
     #
     # Command
     #
-    def cmd(self, cmd: str, *args: t.Any) -> tmux_cmd:
+    def cmd(
+        self, cmd: str, *args: t.Any, target: t.Optional[t.Union[str, int]] = None
+    ) -> tmux_cmd:
         """Execute tmux subcommand within session context.
 
-        Automatically adds ``-t`` for object's session ID to the command. Pass ``-t``
-        in args to override.
+        Automatically binds target by adding  ``-t`` for object's session ID to the
+        command. Pass ``target`` to keyword arguments to override.
 
         Examples
         --------
@@ -157,28 +160,28 @@ class Session(Obj, EnvironmentMixin):
         ... 'new-window', '-P', '-F#{window_id}').stdout[0], server=session.server)
         Window(@... ...:..., Session($1 libtmux_...))
 
+        Parameters
+        ----------
+        target : str, optional
+            Optional custom target override. By default, the target is the session ID.
+
         Returns
         -------
         :meth:`server.cmd`
 
         Notes
         -----
+        .. versionchanged:: 0.34
+
+           Passing target by ``-t`` is ignored. Use ``target`` keyword argument instead.
+
         .. versionchanged:: 0.8
 
             Renamed from ``.tmux`` to ``.cmd``.
         """
-        # if -t is not set in any arg yet
-        if not any("-t" in str(x) for x in args):
-            # insert -t immediately after 1st arg, as per tmux format
-            new_args: t.Tuple[str, ...] = ()
-            assert isinstance(self.session_id, str)
-            new_args += (
-                "-t",
-                self.session_id,
-            )
-            new_args += args
-            args = new_args
-        return self.server.cmd(cmd, *args)
+        if target is None:
+            target = self.session_id
+        return self.server.cmd(cmd, *args, target=target)
 
     """
     Commands (tmux-like)
@@ -355,9 +358,9 @@ class Session(Obj, EnvironmentMixin):
         # Note that we also provide the session ID here, since cmd()
         # will not automatically add it as there is already a '-t'
         # argument provided.
-        target = f"-t{self.session_id}:{target_window}"
+        target = f"{self.session_id}:{target_window}"
 
-        proc = self.cmd("select-window", target)
+        proc = self.cmd("select-window", target=target)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -494,7 +497,7 @@ class Session(Obj, EnvironmentMixin):
         ------
         :exc:`exc.LibTmuxException`
         """
-        proc = self.cmd("switch-client", "-t%s" % self.session_id)
+        proc = self.cmd("switch-client")
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -536,11 +539,14 @@ class Session(Obj, EnvironmentMixin):
     def new_window(
         self,
         window_name: t.Optional[str] = None,
+        *,
         start_directory: None = None,
         attach: bool = False,
         window_index: str = "",
         window_shell: t.Optional[str] = None,
         environment: t.Optional[t.Dict[str, str]] = None,
+        direction: t.Optional[WindowDirection] = None,
+        target_window: t.Optional[str] = None,
     ) -> "Window":
         """Create new window, returns new :class:`Window`.
 
@@ -566,10 +572,52 @@ class Session(Obj, EnvironmentMixin):
                 useful for long-running processes where the closing of the
                 window upon completion is desired.
 
+        direction : WindowDirection, optional
+            Insert window before or after target window (tmux 3.2+).
+
+        target_window : str, optional
+            Used by :meth:`Window.new_window` to specify the target window.
+
         .. versionchanged:: 0.28.0
 
            ``attach`` default changed from ``True`` to ``False``.
 
+        See Also
+        --------
+        :meth:`Window.new_window()`
+
+        Examples
+        --------
+        .. ::
+            >>> import pytest
+            >>> from libtmux.common import has_lt_version
+            >>> if has_lt_version('3.2'):
+            ...     pytest.skip('direction doctests require tmux 3.2 or newer')
+        >>> window_initial = session.new_window(window_name='Example')
+        >>> window_initial
+        Window(@... 2:Example, Session($1 libtmux_...))
+        >>> window_initial.window_index
+        '2'
+
+        >>> window_before = session.new_window(
+        ... window_name='Window before', direction=WindowDirection.Before)
+        >>> window_initial.refresh()
+        >>> window_before
+        Window(@... 1:Window before, Session($1 libtmux_...))
+        >>> window_initial
+        Window(@... 3:Example, Session($1 libtmux_...))
+
+        >>> window_after = session.new_window(
+        ... window_name='Window after', direction=WindowDirection.After)
+        >>> window_initial.refresh()
+        >>> window_after.refresh()
+        >>> window_after
+        Window(@... 3:Window after, Session($1 libtmux_...))
+        >>> window_initial
+        Window(@... 4:Example, Session($1 libtmux_...))
+        >>> window_before
+        Window(@... 1:Window before, Session($1 libtmux_...))
+
         Returns
         -------
         :class:`Window`
@@ -590,11 +638,6 @@ class Session(Obj, EnvironmentMixin):
         if window_name is not None and isinstance(window_name, str):
             window_args += ("-n", window_name)
 
-        window_args += (
-            # empty string for window_index will use the first one available
-            f"-t{self.session_id}:{window_index}",
-        )
-
         if environment:
             if has_gte_version("3.0"):
                 for k, v in environment.items():
@@ -604,10 +647,33 @@ class Session(Obj, EnvironmentMixin):
                     "Environment flag ignored, requires tmux 3.0 or newer.",
                 )
 
+        if direction is not None:
+            if has_gte_version("3.2"):
+                window_args += (WINDOW_DIRECTION_FLAG_MAP[direction],)
+            else:
+                logger.warning(
+                    "Direction flag ignored, requires tmux 3.1 or newer.",
+                )
+
+        target: t.Optional[str] = None
+        if window_index is not None:
+            # empty string for window_index will use the first one available
+            target = f"{self.session_id}:{window_index}"
+        if target_window:
+            if has_gte_version("3.2"):
+                target = target_window
+            else:
+                logger.warning(
+                    "Window target ignored, requires tmux 3.1 or newer.",
+                )
+        elif window_index is not None:
+            # empty string for window_index will use the first one available
+            window_args += (f"-t{self.session_id}:{window_index}",)
+
         if window_shell:
             window_args += (window_shell,)
 
-        cmd = self.cmd("new-window", *window_args)
+        cmd = self.cmd("new-window", *window_args, target=target)
 
         if cmd.stderr:
             raise exc.LibTmuxException(cmd.stderr)
@@ -636,11 +702,11 @@ class Session(Obj, EnvironmentMixin):
         """
         if target_window:
             if isinstance(target_window, int):
-                target = "-t%s:%d" % (self.window_name, target_window)
+                target = "%s:%d" % (self.window_name, target_window)
             else:
-                target = "-t%s" % target_window
+                target = "%s" % target_window
 
-        proc = self.cmd("kill-window", target)
+        proc = self.cmd("kill-window", target=target)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -737,7 +803,7 @@ class Session(Obj, EnvironmentMixin):
             category=DeprecationWarning,
             stacklevel=2,
         )
-        proc = self.cmd("attach-session", "-t%s" % self.session_id)
+        proc = self.cmd("attach-session")
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -758,7 +824,7 @@ class Session(Obj, EnvironmentMixin):
             category=DeprecationWarning,
             stacklevel=2,
         )
-        proc = self.cmd("kill-session", "-t%s" % self.session_id)
+        proc = self.cmd("kill-session")
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
